@@ -503,8 +503,13 @@ class TopicModelTuner:
                 self._tune, adata, parallel = n_workers>1, n_workers = n_workers,
             )
 
+        worker_iters = np.array([self.iters//n_workers]*n_workers)
+        remaining_iters = self.iters % n_workers
+        if remaining_iters > 0:
+            worker_iters[np.arange(remaining_iters)]+=1
+
         Parallel(n_jobs=n_workers, verbose = 0)\
-            (delayed(tune_func)(worker_number = i) for i in range(n_workers))
+            (delayed(tune_func)(worker_number = i, iters = n_iters) for i, n_iters in enumerate(worker_iters))
 
         self.print()
         time.sleep(0.05)
@@ -514,7 +519,7 @@ class TopicModelTuner:
 
     @adi.wraps_modelfunc(tmi.fetch_split_train_test, 
         fill_kwargs = ['all_data', 'train_data', 'test_data'])
-    def _tune(self, worker_number = 0, n_workers = 1, parallel = False,*, 
+    def _tune(self, worker_number = 0, iters = 5, n_workers = 1, parallel = False,*, 
         all_data, train_data, test_data):
 
         if isinstance(self.cv, int):
@@ -565,9 +570,9 @@ class TopicModelTuner:
 
                     try:
                         self.study.optimize(
-                            trial_func, n_trials = remaining_trials//n_workers, 
+                            trial_func, n_trials = iters, 
                             callbacks = [_print_study] if not parallel else [partial(_log_progress, worker_number = worker_number, num_trials = self.iters)],
-                            catch = (ValueError),
+                            catch = (ModelParamError,),
                         )
                     except KeyboardInterrupt:
                         pass
